#!/bin/sh
#
# This script is responsible for installing the Comtrol Rocketport driver
#

if [ `whoami` != root ]; then
	echo "You must be root to install the device driver!"
	exit 1
fi

#
# Check to see whether or not mod_rocket.o was built; if it wasn't built,
# we don't need to install it.
#
if [ -f mod_rocket.o ]; then
	OBJS="mod_rocket.o rocket.o"
else
	OBJS=rocket.o
fi

# Install a copy of the driver in the version independent location
if [ ! -d /lib/modules ]; then 
	mkdir -p /lib/modules
fi

cp $OBJS /lib/modules

# Install a copy of the driver in a kernel version specific location
if [ -f .kver ]; then
    KVER=`cat .kver`;
else
    KVER=`grep UTS_RELEASE /usr/include/linux/version.h | \
	awk '{print $3}' | tr -d \"`
fi
RVER=`uname -r`
echo " "
echo "Installing Rocketport driver for Linux $KVER"
echo " "
if [ $KVER != $RVER ]; then
    echo "WARNING: The current kernel is actually version $RVER."
    echo " "
fi

#
# Actually install the kernel module
#
if [ ! -d /lib/modules/$KVER/misc ]; then 
	mkdir -p /lib/modules/$KVER/misc
fi

cp $OBJS /lib/modules/$KVER/misc

#
# If the modules version wasn't built, remove it from the install tree, 
# lest we get led astray
# 
if [ ! -f mod_rocket.o ]; then
    rm -f /lib/modules/mod_rocket.o /lib/modules/$KVER/misc/mod_rocket.o
fi

#
# OK, now we install the installation script 
#
if [ -d /etc/rc.d/init.d ]; then 
	# This is a RedHat or other system using a System V init scheme

        # Remove old-style rc.script
        rm -f /etc/rc.d/init.d/rc.rocket /etc/rc.d/rc?.d/[SK]??rc.rocket
	if [ ! -f /etc/rc.d/init.d/rocket ]; then
		echo "You are using a system which uses the System V init"
		echo "scheme.  The initialization script has been installed"
		echo "in /etc/rc.d/init.d and it has been automatically "
		echo "set up to be run when you reboot"

		cp rc.rocket /etc/rc.d/init.d/rocket
		ln -sf ../init.d/rocket /etc/rc.d/rc2.d/S83rocket
		ln -sf ../init.d/rocket /etc/rc.d/rc3.d/S83rocket
		ln -sf ../init.d/rocket /etc/rc.d/rc5.d/S83rocket
		ln -sf ../init.d/rocket /etc/rc.d/rc0.d/K18rocket
		ln -sf ../init.d/rocket /etc/rc.d/rc1.d/K18rocket
		ln -sf ../init.d/rocket /etc/rc.d/rc6.d/K18rocket
	fi

	if [ -f /etc/rc.d/rc.rocket ]; then
		echo "You have an old /etc/rc.d/rc.rocket script"
		echo "After checking to make sure it is no longer being used"
		echo "you should delete it."
	fi
elif [ -d /etc/init.d ]; then 
	# This is a Debian system

        # Remove old-style rc.script
        rm -f /etc/init.d/rc.rocket /etc/rc?.d/[SK]??rc.rocket
	if [ ! -f /etc/init.d/rocket ]; then
		echo "You are using a system which uses the Debian "
		echo "System V init directory layout.  The initialization"
		echo "script has been installed in /etc/init.d and it"
		echo "has been automatically set up to be run when you reboot"

		ln -sf ../init.d/rocket /etc/rc2.d/S83rocket
		ln -sf ../init.d/rocket /etc/rc3.d/S83rocket
		ln -sf ../init.d/rocket /etc/rc5.d/S83rocket
		ln -sf ../init.d/rocket /etc/rc0.d/K20rocket
		ln -sf ../init.d/rocket /etc/rc1.d/K20rocket
		ln -sf ../init.d/rocket /etc/rc6.d/K20rocket
	fi
	cp rc.rocket /etc/init.d/rocket
else
        # This must be a Slackware or other non-SysV init system
	if [ ! -f /etc/rc.d/rc.rocket ]; then
		echo "The initialization script has been installed in "
		echo "/etc/rc.d/rc.rocket.  You will need to edit your "
		echo "/etc/rc files to run /etc/rc.d/rc.rocket"

		if [ ! -d /etc/rc.d ]; then 
			mkdir -p /etc/rc.d
		fi

		cp rc.rocket /etc/rc.d
	fi
fi

#
# Copy in the rocketport.conf file, if isn't already installed
#
if [ ! -f /etc/rocketport.conf ]; then
	cp rocketport.conf /etc
	echo "Make sure you check and edit the /etc/rocketport.conf file!"
fi

#
# Install the setrocket program
#
cp setrocket /bin/setrocket
strip /bin/setrocket
chmod 755 /bin/setrocket

